functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun CN(s:string) = ([T.CN(A.ConS s,!line,!line)],s)
fun RNs(s:string) = ([T.RNs(A.ConR s,!line,!line)],s)
fun RNp(s:string) = ([T.RNp(A.ConR s,!line,!line)],s)
fun PN(s:string) = ([T.PN(A.ConS s,!line,!line)],s)
fun IVs(s:string) = ([T.IVs(A.ConS s,!line,!line)],s)
fun IVp(s:string) = ([T.IVp(A.ConS s,!line,!line)],s)
fun TVs(s:string) = ([T.TVs(A.ConR s,!line,!line)],s)
fun TVp(s:string) = ([T.TVp(A.ConR s,!line,!line)],s)
fun CAs(s:string) = ([T.CAs(A.ConS s,!line,!line)],s)
fun CAp(s:string) = ([T.CAp(A.ConS s,!line,!line)],s)
fun IAComp(s:string) = ([T.IAComp(A.ConR s,!line,!line)],s)
fun P(s:string) = ([T.P(A.ConR s,!line,!line)],s)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"T",#"V",1),
(#"X",#"`",1),
(#"c",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"m",1),
(#"o",#"r",1),
(#"u",#"u",1),
(#"w",#"\194",1),
(#"\196",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"j",#"j",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"W",#"W",18),
(#"a",#"a",19),
(#"b",#"b",20),
(#"d",#"d",21),
(#"e",#"e",22),
(#"g",#"g",23),
(#"i",#"i",24),
(#"k",#"k",25),
(#"l",#"l",26),
(#"n",#"n",27),
(#"s",#"s",28),
(#"t",#"t",29),
(#"v",#"v",30),
(#"\195",#"\195",31)], [0]), ([], [45]), ([(#"\t",#"\t",213),
(#" ",#" ",213)], [0, 45]), ([], [1]), ([], [2, 45]), ([(#"l",#"l",105),
(#"n",#"n",210)], [45]), ([(#"e",#"e",201),
(#"r",#"r",202)], [45]), ([(#"i",#"i",196)], [45]), ([(#"i",#"i",191),
(#"m",#"m",192)], [45]), ([(#"r",#"r",188)], [45]), ([(#"a",#"a",175),
(#"u",#"u",176)], [45]), ([(#"t",#"t",169)], [45]), ([(#"e",#"e",166)], [45]), ([(#"e",#"e",163)], [45]), ([(#"a",#"a",153)], [45]), ([(#"a",#"a",147)], [45]), ([(#"o",#"o",145)], [45]), ([(#"c",#"c",120),
(#"p",#"p",121),
(#"t",#"t",122)], [45]), ([(#"a",#"a",116)], [45]), ([(#"l",#"l",105),
(#"r",#"r",106)], [45]), ([(#"r",#"r",99)], [45]), ([(#"a",#"a",95),
(#"e",#"e",96),
(#"i",#"i",97)], [45]), ([(#"i",#"i",91)], [45]), ([(#"e",#"e",86)], [45]), ([(#"n",#"n",83),
(#"s",#"s",84)], [45]), ([(#"e",#"e",73)], [45]), ([(#"i",#"i",67)], [45]), ([(#"e",#"e",62)], [45]), ([(#"c",#"c",48),
(#"i",#"i",49)], [45]), ([(#"o",#"o",43)], [45]), ([(#"o",#"o",41)], [45]), ([(#"\164",#"\164",32)], [45]), ([(#"l",#"l",33)], []), ([(#"t",#"t",34)], []), ([(#"e",#"e",35)], []), ([(#"r",#"r",36)], []), ([(#" ",#" ",37)], []), ([(#"a",#"a",38)], []), ([(#"l",#"l",39)], []), ([(#"s",#"s",40)], []), ([], [37]), ([(#"n",#"n",42)], []), ([], [5]), ([(#"l",#"l",44)], []), ([(#"l",#"l",45)], []), ([(#"e",#"e",46)], [32]), ([(#"r",#"r",47)], [32, 33]), ([], [32]), ([(#"h",#"h",52)], []), ([(#"n",#"n",50)], []), ([(#"d",#"d",51)], []), ([], [4]), ([(#"\195",#"\195",53)], []), ([(#"\182",#"\182",54)], []), ([(#"n",#"n",55)], []), ([(#"e",#"e",56)], []), ([(#"r",#"r",57)], []), ([(#" ",#" ",58)], []), ([(#"a",#"a",59)], []), ([(#"l",#"l",60)], []), ([(#"s",#"s",61)], []), ([], [36]), ([(#"t",#"t",63)], []), ([(#"t",#"t",64)], []), ([(#"e",#"e",65)], []), ([(#"r",#"s",66)], [34, 35]), ([], [34]), ([(#"e",#"e",68)], []), ([(#"b",#"b",69)], []), ([(#"e",#"e",70),
(#"t",#"t",71)], []), ([(#"n",#"n",72)], []), ([], [44]), ([], [43]), ([(#"i",#"i",74),
(#"n",#"n",75)], []), ([(#"n",#"n",80)], []), ([(#"n",#"n",76)], []), ([(#"e",#"e",77),
(#"t",#"t",78)], []), ([(#"n",#"n",79)], []), ([], [42]), ([], [41]), ([(#"e",#"e",81)], [8]), ([(#"n",#"n",82),
(#"s",#"s",82)], [8]), ([], [8]), ([], [38]), ([(#"t",#"t",85)], []), ([], [3]), ([(#"s",#"s",87)], []), ([(#"u",#"u",88)], []), ([(#"n",#"n",89)], []), ([(#"d",#"d",90)], []), ([], [29]), ([(#"n",#"n",92)], []), ([(#"e",#"e",93)], [7]), ([(#"n",#"n",94),
(#"s",#"s",94)], [7]), ([], [7]), ([(#"s",#"s",98)], []), ([(#"n",#"n",98),
(#"r",#"r",98)], []), ([(#"e",#"e",98)], []), ([], [6]), ([(#"a",#"a",100)], []), ([(#"u",#"u",101)], []), ([(#"n",#"n",102)], []), ([(#"e",#"e",103)], [30]), ([(#"r",#"r",104)], [30, 31]), ([], [30]), ([(#"l",#"l",114)], []), ([(#"b",#"b",107)], []), ([(#"e",#"e",108)], []), ([(#"i",#"i",109)], []), ([(#"t",#"t",110)], []), ([(#"e",#"e",111)], []), ([(#"n",#"n",112),
(#"t",#"t",113)], []), ([], [39]), ([], [40]), ([(#"e",#"e",115)], []), ([], [9]), ([(#"l",#"l",117)], []), ([(#"d",#"d",118)], []), ([(#"i",#"i",119)], []), ([], [14]), ([(#"h",#"h",138)], []), ([(#"a",#"a",133)], []), ([(#"a",#"a",123),
(#"u",#"u",124)], []), ([(#"d",#"d",131)], []), ([(#"d",#"d",125)], []), ([(#"e",#"e",126)], []), ([(#"n",#"n",127)], []), ([(#"t",#"t",128)], []), ([(#"e",#"e",129)], [23]), ([(#"n",#"n",130)], []), ([], [23]), ([(#"t",#"t",132)], []), ([], [28]), ([(#"n",#"n",134)], []), ([(#"i",#"i",135)], []), ([(#"e",#"e",136)], []), ([(#"n",#"n",137)], []), ([], [18]), ([(#"w",#"w",139)], []), ([(#"e",#"e",140)], []), ([(#"s",#"s",141)], []), ([(#"t",#"t",142)], []), ([(#"e",#"e",143)], []), ([(#"r",#"r",144)], []), ([], [26]), ([(#"m",#"m",146)], []), ([], [15]), ([(#"c",#"c",148)], []), ([(#"h",#"h",149)], []), ([(#"b",#"b",150)], []), ([(#"a",#"a",151)], []), ([(#"r",#"r",152)], []), ([], [24]), ([(#"d",#"d",154),
(#"n",#"n",155),
(#"r",#"r",156)], []), ([(#"r",#"r",160)], []), ([(#"n",#"n",159)], []), ([(#"i",#"i",157)], []), ([(#"a",#"a",158)], []), ([], [13]), ([], [19]), ([(#"i",#"i",161)], []), ([(#"d",#"d",162)], []), ([], [16]), ([(#"i",#"i",164)], []), ([(#"n",#"n",165)], []), ([(#"e",#"e",82)], [8]), ([(#"d",#"d",167)], []), ([(#"e",#"e",168)], []), ([(#"n",#"n",115),
(#"r",#"r",115)], [9]), ([(#"a",#"a",170)], []), ([(#"l",#"l",171)], []), ([(#"i",#"i",172)], []), ([(#"e",#"e",173)], []), ([(#"n",#"n",174)], []), ([], [17]), ([(#"u",#"u",180)], []), ([(#"n",#"n",177)], []), ([(#"d",#"d",178)], []), ([(#"e",#"e",179)], [21]), ([], [21]), ([(#"p",#"p",181)], []), ([(#"t",#"t",182)], []), ([(#"s",#"s",183)], []), ([(#"t",#"t",184)], []), ([(#"a",#"a",185)], []), ([(#"d",#"d",186)], []), ([(#"t",#"t",187)], []), ([], [27]), ([(#"a",#"a",189)], []), ([(#"u",#"u",190)], []), ([], [20]), ([(#"n",#"n",195)], []), ([(#"i",#"i",193)], []), ([(#"l",#"l",194)], []), ([], [12]), ([(#"e",#"e",94)], [7]), ([(#"e",#"e",197)], []), ([(#"t",#"t",198)], []), ([(#"e",#"e",199)], []), ([(#"r",#"r",200)], []), ([], [11]), ([(#"r",#"r",207)], []), ([(#"u",#"u",203)], []), ([(#"d",#"d",204)], []), ([(#"e",#"e",205)], []), ([(#"r",#"r",206)], []), ([], [25]), ([(#"g",#"g",208)], []), ([(#"e",#"e",209)], [22]), ([], [22]), ([(#"n",#"n",211)], []), ([(#"a",#"a",212)], []), ([], [10]), ([(#"\t",#"\t",213),
(#" ",#" ",213)], [0])]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVs(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVp(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Det(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQ(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQ(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQ(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction11 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction12 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction13 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction14 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Waldi"))
fun yyAction15 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction16 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction17 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction18 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction19 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Mann"))
fun yyAction20 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Frau"))
fun yyAction21 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Hund"))
fun yyAction22 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Berg"))
fun yyAction23 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Student"))
fun yyAction24 (strm, lastMatch : yymatch) = (yystrm := strm; (RNs "Nachbar"))
fun yyAction25 (strm, lastMatch : yymatch) = (yystrm := strm; (RNs "Bruder"))
fun yyAction26 (strm, lastMatch : yymatch) = (yystrm := strm;
      (RNs "Schwester"))
fun yyAction27 (strm, lastMatch : yymatch) = (yystrm := strm;
      (RNs "Hauptstadt"))
fun yyAction28 (strm, lastMatch : yymatch) = (yystrm := strm; (CN "Stadt"))
fun yyAction29 (strm, lastMatch : yymatch) = (yystrm := strm; (CAs "gesund"))
fun yyAction30 (strm, lastMatch : yymatch) = (yystrm := strm; (CAs "braun"))
fun yyAction31 (strm, lastMatch : yymatch) = (yystrm := strm; (CAp "braun"))
fun yyAction32 (strm, lastMatch : yymatch) = (yystrm := strm; (CAs "toll"))
fun yyAction33 (strm, lastMatch : yymatch) = (yystrm := strm; (CAp "toll"))
fun yyAction34 (strm, lastMatch : yymatch) = (yystrm := strm; (CAs "nett"))
fun yyAction35 (strm, lastMatch : yymatch) = (yystrm := strm; (CAp "nette"))
fun yyAction36 (strm, lastMatch : yymatch) = (yystrm := strm;
      (IAComp "schöner als"))
fun yyAction37 (strm, lastMatch : yymatch) = (yystrm := strm;
      (IAComp "älter als"))
fun yyAction38 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction39 (strm, lastMatch : yymatch) = (yystrm := strm; (IVp "arbeiten"))
fun yyAction40 (strm, lastMatch : yymatch) = (yystrm := strm; (IVs "arbeiten"))
fun yyAction41 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "kennen"))
fun yyAction42 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "kennen"))
fun yyAction43 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "lieben"))
fun yyAction44 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "lieben"))
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
