functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun PN(s:string) = ([T.PN(A.ConS s,!line,!line)],s)
fun CNn s t = ([T.CNn(A.ConS s,!line,!line)],t)
fun CNg s t = ([T.CNg(A.ConS s,!line,!line)],t)
fun CNd s t = ([T.CNd(A.ConS s,!line,!line)],t)
fun CNa s t = ([T.CNa(A.ConS s,!line,!line)],t)
fun RNsn s t = ([T.RNsn(A.ConR s,!line,!line)],t)
fun RNsg s t = ([T.RNsg(A.ConR s,!line,!line)],t)
fun RNsd s t = ([T.RNsd(A.ConR s,!line,!line)],t)
fun RNsa s t = ([T.RNsa(A.ConR s,!line,!line)],t)
fun RNpn s t = ([T.RNpn(A.ConR s,!line,!line)],t)
fun RNpg s t = ([T.RNpg(A.ConR s,!line,!line)],t)
fun RNpd s t = ([T.RNpd(A.ConR s,!line,!line)],t)
fun RNpa s t = ([T.RNpa(A.ConR s,!line,!line)],t)
fun IVs(s:string) = ([T.IVs(A.ConS s,!line,!line)],s)
fun IVp(s:string) = ([T.IVp(A.ConS s,!line,!line)],s)
fun TVs(s:string) = ([T.TVs(A.ConR s,!line,!line)],s)
fun TVp(s:string) = ([T.TVp(A.ConR s,!line,!line)],s)
fun CAsn(s:string) = ([T.CAsn(A.ConS s,!line,!line)],s)
fun CAsg(s:string) = ([T.CAsg(A.ConS s,!line,!line)],s)
fun CAsd(s:string) = ([T.CAsd(A.ConS s,!line,!line)],s)
fun CAsa(s:string) = ([T.CAsa(A.ConS s,!line,!line)],s)
fun CApn(s:string) = ([T.CApn(A.ConS s,!line,!line)],s)
fun CApg(s:string) = ([T.CApg(A.ConS s,!line,!line)],s)
fun CApd(s:string) = ([T.CApd(A.ConS s,!line,!line)],s)
fun CApa(s:string) = ([T.CApa(A.ConS s,!line,!line)],s)
fun IAComp(s:string) = ([T.IAComp(A.ConR s,!line,!line)],s)
fun P(s:string) = ([T.P(A.ConR s,!line,!line)],s)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[
([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"T",#"V",1),
(#"X",#"`",1),
(#"c",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"m",1),
(#"o",#"r",1),
(#"u",#"u",1),
(#"w",#"\194",1),
(#"\196",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"W",#"W",18),
(#"a",#"a",19),
(#"b",#"b",20),
(#"d",#"d",21),
(#"e",#"e",22),
(#"g",#"g",23),
(#"i",#"i",24),
(#"j",#"j",25),
(#"k",#"k",26),
(#"l",#"l",27),
(#"n",#"n",28),
(#"s",#"s",29),
(#"t",#"t",30),
(#"v",#"v",31),
(#"\195",#"\195",32)], [0]), ([], [99]), ([(#"\t",#"\t",243),
(#" ",#" ",243)], [0, 99]), ([], [1]), ([], [2, 99]), ([(#"l",#"l",137),
(#"n",#"n",240)], [99]), ([(#"r",#"r",234)], [99]), ([(#"i",#"i",229)], [99]), ([(#"i",#"i",113),
(#"m",#"m",226)], [99]), ([(#"r",#"r",223)], [99]), ([(#"a",#"a",209),
(#"u",#"u",210)], [99]), ([(#"t",#"t",203)], [99]), ([(#"e",#"e",198)], [99]), ([(#"e",#"e",197)], [99]), ([(#"a",#"a",185)], [99]), ([(#"a",#"a",177)], [99]), ([(#"o",#"o",175)], [99]), ([(#"c",#"c",153),
(#"p",#"p",154),
(#"t",#"t",155)], [99]), ([(#"a",#"a",149)], [99]), ([(#"l",#"l",137),
(#"r",#"r",138)], [99]), ([(#"r",#"r",128)], [99]), ([(#"a",#"a",120),
(#"e",#"e",121),
(#"i",#"i",122)], [99]), ([(#"i",#"i",113)], [99]), ([(#"e",#"e",108)], [99]), ([(#"n",#"n",105),
(#"s",#"s",106)], [99]), ([(#"e",#"e",99)], [99]), ([(#"e",#"e",86)], [99]), ([(#"i",#"i",80)], [99]), ([(#"e",#"e",72)], [99]), ([(#"c",#"c",58),
(#"i",#"i",59)], [99]), ([(#"a",#"a",44),
(#"o",#"o",45)], [99]), ([(#"o",#"o",42)], [99]), ([(#"\164",#"\164",33)], [99]), ([(#"l",#"l",34)], []), ([(#"t",#"t",35)], []), ([(#"e",#"e",36)], []), ([(#"r",#"r",37)], []), ([(#" ",#" ",38)], []), ([(#"a",#"a",39)], []), ([(#"l",#"l",40)], []), ([(#"s",#"s",41)], []), ([], [89]), ([(#"n",#"n",43)], []), ([], [5]), ([(#"n",#"n",53)], []), ([(#"l",#"l",46)], []), ([(#"l",#"l",47)], []), ([(#"e",#"e",48)], []), ([(#"m",#"m",49),
(#"n",#"n",50),
(#"r",#"r",51),
(#"s",#"s",52)], [72, 75, 76, 79]), ([], [74]), ([], [73, 75, 78]), ([], [72, 73, 74, 77]), ([], [72, 75]), ([(#"z",#"z",54)], []), ([(#"e",#"e",55),
(#"t",#"t",56)], []), ([(#"n",#"n",57)], []), ([], [98]), ([], [97]), ([(#"h",#"h",62)], []), ([(#"n",#"n",60)], []), ([(#"d",#"d",61)], []), ([], [4]), ([(#"\195",#"\195",63)], []), ([(#"\182",#"\182",64)], []), ([(#"n",#"n",65)], []), ([(#"e",#"e",66)], []), ([(#"r",#"r",67)], []), ([(#" ",#" ",68)], []), ([(#"a",#"a",69)], []), ([(#"l",#"l",70)], []), ([(#"s",#"s",71)], []), ([], [88]), ([(#"t",#"t",73)], []), ([(#"t",#"t",74)], []), ([(#"e",#"e",75)], []), ([(#"m",#"m",76),
(#"n",#"n",77),
(#"r",#"r",78),
(#"s",#"s",79)], [80, 83, 84, 87]), ([], [82]), ([], [81, 83, 86]), ([], [80, 81, 82, 85]), ([], [80, 83]), ([(#"e",#"e",81)], []), ([(#"b",#"b",82)], []), ([(#"e",#"e",83),
(#"t",#"t",84)], []), ([(#"n",#"n",85)], []), ([], [96]), ([], [95]), ([(#"i",#"i",87),
(#"n",#"n",88)], []), ([(#"n",#"n",93)], []), ([(#"n",#"n",89)], []), ([(#"e",#"e",90),
(#"t",#"t",91)], []), ([(#"n",#"n",92)], []), ([], [94]), ([], [93]), ([(#"e",#"e",94)], [14, 17]), ([(#"m",#"m",95),
(#"n",#"n",96),
(#"r",#"r",97),
(#"s",#"s",98)], [14, 17]), ([], [16]), ([], [17]), ([], [15, 16]), ([], [15]), ([(#"d",#"d",100)], []), ([(#"e",#"e",101)], []), ([(#"m",#"m",102),
(#"r",#"r",103),
(#"s",#"s",104)], [18, 21]), ([], [20]), ([], [18, 19, 20, 21]), ([], [18, 19, 21]), ([], [90]), ([(#"t",#"t",107)], []), ([], [3]), ([(#"s",#"s",109)], []), ([(#"u",#"u",110)], []), ([(#"n",#"n",111)], []), ([(#"d",#"d",112)], []), ([], [63]), ([(#"n",#"n",114)], []), ([(#"e",#"e",115)], [10, 13]), ([(#"m",#"m",116),
(#"n",#"n",117),
(#"r",#"r",118),
(#"s",#"s",119)], [10, 13]), ([], [12]), ([], [13]), ([], [11, 12]), ([], [11]), ([(#"s",#"s",123)], []), ([(#"m",#"m",124),
(#"n",#"n",125),
(#"r",#"r",126),
(#"s",#"s",127)], []), ([(#"e",#"e",123)], []), ([], [6, 9]), ([], [8]), ([], [9]), ([], [6, 7, 8]), ([], [7]), ([(#"a",#"a",129)], []), ([(#"u",#"u",130)], []), ([(#"n",#"n",131)], []), ([(#"e",#"e",132)], []), ([(#"m",#"m",133),
(#"n",#"n",134),
(#"r",#"r",135),
(#"s",#"s",136)], [64, 67, 68, 71]), ([], [66]), ([], [65, 67, 70]), ([], [64, 65, 66, 69]), ([], [64, 67]), ([(#"l",#"l",146)], []), ([(#"b",#"b",139)], []), ([(#"e",#"e",140)], []), ([(#"i",#"i",141)], []), ([(#"t",#"t",142)], []), ([(#"e",#"e",143)], []), ([(#"n",#"n",144),
(#"t",#"t",145)], []), ([], [91]), ([], [92]), ([(#"e",#"e",147)], []), ([(#"n",#"n",102),
(#"r",#"r",148)], [18, 21]), ([], [19]), ([(#"l",#"l",150)], []), ([(#"d",#"d",151)], []), ([(#"i",#"i",152)], []), ([], [26]), ([(#"h",#"h",168)], []), ([(#"a",#"a",163)], []), ([(#"u",#"u",156)], []), ([(#"d",#"d",157)], []), ([(#"e",#"e",158)], []), ([(#"n",#"n",159)], []), ([(#"t",#"t",160)], []), ([(#"e",#"e",161)], [43]), ([(#"n",#"n",162)], []), ([], [44, 45, 46]), ([(#"n",#"n",164)], []), ([(#"i",#"i",165)], []), ([(#"e",#"e",166)], []), ([(#"n",#"n",167)], []), ([], [30]), ([(#"w",#"w",169)], []), ([(#"e",#"e",170)], []), ([(#"s",#"s",171)], []), ([(#"t",#"t",172)], []), ([(#"e",#"e",173)], []), ([(#"r",#"r",174)], []), ([], [51, 52, 53, 54]), ([(#"m",#"m",176)], []), ([], [27]), ([(#"c",#"c",178)], []), ([(#"h",#"h",179)], []), ([(#"b",#"b",180)], []), ([(#"a",#"a",181)], []), ([(#"r",#"r",182)], []), ([(#"n",#"n",183),
(#"s",#"s",184)], [55]), ([], [57, 58]), ([], [56]), ([(#"d",#"d",186),
(#"n",#"n",187),
(#"r",#"r",188)], []), ([(#"r",#"r",194)], []), ([(#"n",#"n",191)], []), ([(#"i",#"i",189)], []), ([(#"a",#"a",190)], []), ([], [25]), ([(#"e",#"e",192)], [31, 33, 34]), ([(#"s",#"s",193)], []), ([], [32]), ([(#"i",#"i",195)], []), ([(#"d",#"d",196)], []), ([], [28]), ([(#"i",#"i",87)], []), ([(#"d",#"d",199)], []), ([(#"e",#"e",200)], []), ([(#"m",#"m",102),
(#"n",#"n",201),
(#"r",#"r",202),
(#"s",#"s",104)], [18, 21]), ([], [21]), ([], [18, 19, 20]), ([(#"a",#"a",204)], []), ([(#"l",#"l",205)], []), ([(#"i",#"i",206)], []), ([(#"e",#"e",207)], []), ([(#"n",#"n",208)], []), ([], [29]), ([(#"u",#"u",215)], []), ([(#"n",#"n",211)], []), ([(#"d",#"d",212)], []), ([(#"e",#"e",213)], [39, 41, 42]), ([(#"s",#"s",214)], []), ([], [40]), ([(#"p",#"p",216)], []), ([(#"t",#"t",217)], []), ([(#"s",#"s",218)], []), ([(#"t",#"t",219)], []), ([(#"a",#"a",220)], []), ([(#"d",#"d",221)], []), ([(#"t",#"t",222)], []), ([], [59, 60, 61, 62]), ([(#"a",#"a",224)], []), ([(#"u",#"u",225)], []), ([], [35, 36, 37, 38]), ([(#"i",#"i",227)], []), ([(#"l",#"l",228)], []), ([], [24]), ([(#"e",#"e",230)], []), ([(#"t",#"t",231)], []), ([(#"e",#"e",232)], []), ([(#"r",#"r",233)], []), ([], [23]), ([(#"u",#"u",235)], []), ([(#"d",#"d",236)], []), ([(#"e",#"e",237)], []), ([(#"r",#"r",238)], []), ([(#"s",#"s",239)], [47, 49, 50]), ([], [48]), ([(#"n",#"n",241)], []), ([(#"a",#"a",242)], []), ([], [22]), ([(#"\t",#"\t",243),
(#" ",#" ",243)], [0])]

    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVs(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVp(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detn(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detg(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detd(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Deta(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQn(!line,!line)],yytext)
      end
fun yyAction11 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQg(!line,!line)],yytext)
      end
fun yyAction12 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQd(!line,!line)],yytext)
      end
fun yyAction13 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQa(!line,!line)],yytext)
      end
fun yyAction14 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQn(!line,!line)],yytext)
      end
fun yyAction15 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQg(!line,!line)],yytext)
      end
fun yyAction16 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQd(!line,!line)],yytext)
      end
fun yyAction17 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQa(!line,!line)],yytext)
      end
fun yyAction18 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQn(!line,!line)],yytext)
      end
fun yyAction19 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQg(!line,!line)],yytext)
      end
fun yyAction20 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQd(!line,!line)],yytext)
      end
fun yyAction21 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQa(!line,!line)],yytext)
      end
fun yyAction22 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction23 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction24 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction25 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction26 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Waldi"))
fun yyAction27 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction28 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction29 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction30 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction31 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Mann" yytext)
      end
fun yyAction32 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Mann" yytext)
      end
fun yyAction33 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Mann" yytext)
      end
fun yyAction34 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Mann" yytext)
      end
fun yyAction35 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Frau" yytext)
      end
fun yyAction36 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Frau" yytext)
      end
fun yyAction37 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Frau" yytext)
      end
fun yyAction38 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Frau" yytext)
      end
fun yyAction39 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Hund" yytext)
      end
fun yyAction40 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Hund" yytext)
      end
fun yyAction41 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Hund" yytext)
      end
fun yyAction42 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Hund" yytext)
      end
fun yyAction43 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Student" yytext)
      end
fun yyAction44 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Student" yytext)
      end
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Student" yytext)
      end
fun yyAction46 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Student" yytext)
      end
fun yyAction47 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Bruder" yytext)
      end
fun yyAction48 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Bruder" yytext)
      end
fun yyAction49 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Bruder" yytext)
      end
fun yyAction50 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Bruder" yytext)
      end
fun yyAction51 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Schwester" yytext)
      end
fun yyAction52 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Schwester" yytext)
      end
fun yyAction53 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Schwester" yytext)
      end
fun yyAction54 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Schwester" yytext)
      end
fun yyAction55 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Nachbar" yytext)
      end
fun yyAction56 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Nachbar" yytext)
      end
fun yyAction57 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Nachbar" yytext)
      end
fun yyAction58 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Nachbar" yytext)
      end
fun yyAction59 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsn "Hauptstadt" yytext)
      end
fun yyAction60 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsg "Hauptstadt" yytext)
      end
fun yyAction61 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsd "Hauptstadt" yytext)
      end
fun yyAction62 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNsa "Hauptstadt" yytext)
      end
fun yyAction63 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "gesund"))
fun yyAction64 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "braun"))
fun yyAction65 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "braun"))
fun yyAction66 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "braun"))
fun yyAction67 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "braun"))
fun yyAction68 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "braun"))
fun yyAction69 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "braun"))
fun yyAction70 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "braun"))
fun yyAction71 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "braun"))
fun yyAction72 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "toll"))
fun yyAction73 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "toll"))
fun yyAction74 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "toll"))
fun yyAction75 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "toll"))
fun yyAction76 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "toll"))
fun yyAction77 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "toll"))
fun yyAction78 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "toll"))
fun yyAction79 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "toll"))
fun yyAction80 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsn "nett"))
fun yyAction81 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsg "nett"))
fun yyAction82 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsd "nett"))
fun yyAction83 (strm, lastMatch : yymatch) = (yystrm := strm; (CAsa "nett"))
fun yyAction84 (strm, lastMatch : yymatch) = (yystrm := strm; (CApn "nett"))
fun yyAction85 (strm, lastMatch : yymatch) = (yystrm := strm; (CApg "nett"))
fun yyAction86 (strm, lastMatch : yymatch) = (yystrm := strm; (CApd "nett"))
fun yyAction87 (strm, lastMatch : yymatch) = (yystrm := strm; (CApa "nett"))
fun yyAction88 (strm, lastMatch : yymatch) = (yystrm := strm;
      (IAComp "schöner als"))
fun yyAction89 (strm, lastMatch : yymatch) = (yystrm := strm;
      (IAComp "älter als"))
fun yyAction90 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction91 (strm, lastMatch : yymatch) = (yystrm := strm; (IVp "arbeiten"))
fun yyAction92 (strm, lastMatch : yymatch) = (yystrm := strm; (IVs "arbeiten"))
fun yyAction93 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "kennen"))
fun yyAction94 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "kennen"))
fun yyAction95 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "lieben"))
fun yyAction96 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "lieben"))
fun yyAction97 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "tanzen"))
fun yyAction98 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "tanzen"))
fun yyAction99 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45, yyAction46,
  yyAction47, yyAction48, yyAction49, yyAction50, yyAction51, yyAction52,
  yyAction53, yyAction54, yyAction55, yyAction56, yyAction57, yyAction58,
  yyAction59, yyAction60, yyAction61, yyAction62, yyAction63, yyAction64,
  yyAction65, yyAction66, yyAction67, yyAction68, yyAction69, yyAction70,
  yyAction71, yyAction72, yyAction73, yyAction74, yyAction75, yyAction76,
  yyAction77, yyAction78, yyAction79, yyAction80, yyAction81, yyAction82,
  yyAction83, yyAction84, yyAction85, yyAction86, yyAction87, yyAction88,
  yyAction89, yyAction90, yyAction91, yyAction92, yyAction93, yyAction94,
  yyAction95, yyAction96, yyAction97, yyAction98, yyAction99])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
