signature PARSE =
  sig
      structure Absyn : ABSYN 
      structure Semantics : SEM

      val parse : unit -> Absyn.absyn list
      val ev : string -> Absyn.absyn list
      val parse_file : string -> Absyn.absyn list list
      val test_file : string ->  unit
      val parse_seq : unit ->  Absyn.absyn list list

      val eval : Absyn.absyn -> Semantics.value
      val evals : string -> Semantics.value list

      val trees : bool ref
      val covertrees : bool ref
      val debug : bool ref
  end  

functor ParseAux(structure Absyn : ABSYN 
                 structure Algebra : PEIRCEfull
                 structure Interface : INTERFACE
                 structure Parser : PARSER
                    sharing type Parser.arg = Interface.arg
                    sharing type Parser.pos = Interface.pos
                    sharing type Parser.result = Absyn.absyn  
                 structure Tokens : NL__TOKENS
                    sharing type Tokens.token = Parser.Token.token
                    sharing type Tokens.svalue = Parser.svalue
                ) : PARSE = 
  struct
    structure Absyn = Absyn 
    structure Semantics = Semantics(structure A = Absyn:ABSYN 
                                    structure P = Algebra:PEIRCEfull)
    val _ = Control.Print.printDepth := 20
    val _ = Control.Print.printLength := 50

    val trees = Parser.trees
    val covertrees = Parser.covertrees 
    val debug = Parser.debug

    fun invoke lexer = 
        Parser.parse(lexer,Interface.error,Interface.nothing)
    fun show result = 
        print ("Absyn: " ^ Absyn.toString result ^ "\n")

    fun parse () =
        let 
            val _ = Interface.init_line()
            val dummyEOF = Tokens.EOF(!Interface.line,!Interface.line)

            fun loop lexer =
                let val (result,lexer) = invoke lexer
                    val ((nextTokens,_),lexer) = Parser.Stream.get lexer
                    val _ = app show result
                in if Parser.sameToken(hd nextTokens,dummyEOF) 
                   then result else loop lexer
                end

            fun reader (n:int) = 
                case (TextIO.inputLine TextIO.stdIn) of
                    SOME s => s | NONE => ""
        in
          loop (Parser.makeLexer reader)
        end

    fun ev (s:string) = 
        let 
            val _ = Interface.init_line()
            val dummyEOF = Tokens.EOF(!Interface.line,!Interface.line)

            fun loop lexer =
                let val (result,lexer) = invoke lexer
                    val ((nextTokens,_),lexer) = Parser.Stream.get lexer
                in if Parser.sameToken(hd nextTokens,dummyEOF) 
                   then (app show result ; result) else loop lexer
                end

            fun string_reader s =
                let 
                    val next = ref s
                in fn _ => !next before next := "" end
            val reader = string_reader s
        in 
            loop (Parser.makeLexer reader)
        end

    val eval = Semantics.eval
    fun evals s = map eval (ev s)

    (* Parse a sequence of sentences separated by DOT, until EOF is found. 
       Accumulate the values of the sentences and return them at EOF.
       Delivers an empty value list for sentences containing a parse error.
     *)

    fun skip lexer eop = (* skip the remaining word up to the given eop-symbol *)
        let val ((nextTokens,_),lexer) = Parser.Stream.get lexer
        in if Parser.sameToken (hd nextTokens, eop)
           then lexer else skip lexer eop
        end


    fun loop_seq lexer = loop' ([],lexer)
    and loop' (acc, lexer) =
        let    
            val dummyEOF = Tokens.EOF(!Interface.line,!Interface.line)
            val ((nextTokens',_),_) = Parser.Stream.get lexer
        in 
            if Parser.sameToken(List.hd nextTokens',dummyEOF) then rev(acc)
            else 
                let
                    val (result,lexer) = invoke lexer 
                    val ((nextTokens,nextWord),lexer) = Parser.Stream.get lexer
                in
                    loop' (result::acc, lexer)
                end
                handle ParseError => 
                       (TextIO.print "Parse Error; ignoring this sentence.\n"; 
                        let val lexer = 
                                skip lexer (Tokens.PUNKT(!Interface.line,
                                                         !Interface.line))
                        in
                            loop'([]::acc,lexer)
                        end)
        end
    (* Don't show trees, and deliver the values at EOF *)
    and parse_file name =
        let 
            val _ = Interface.init_line()
            val stream = TextIO.openIn name
            fun reader i = TextIO.inputN(stream,i)        
            val _ = (trees := false)
        in loop_seq (Parser.makeLexer reader)
           before TextIO.closeIn stream
        end
    (* Show trees of each sentence, but postpone delivering the values to EOF *)
    and parse_seq () = 
        let val _ = Interface.init_line() 
            fun reader (_:int) = 
                case (TextIO.inputLine TextIO.stdIn) of
                    SOME s => s | NONE => ""
            val _ = (trees := true)
        in loop_seq (Parser.makeLexer reader)
        end
    (* Parse sentences of a file and write its abstract syntax to file.out *)
    fun test_file name =
        let 
            val _ = Interface.init_line()
            val stream = TextIO.openIn name
            fun reader i = TextIO.inputN(stream,i)        
            val _ = (trees := false)
            val outStream = TextIO.openOut (name ^ ".out")

            fun show result = 
                (TextIO.print ("Absyn: " ^ Absyn.toString result ^ "\n");
                 TextIO.output (outStream, "Absyn: " ^ Absyn.toString result ^ "\n"))

            fun loop lexer = 
                let    
                    val dummyEOF = Tokens.EOF(!Interface.line,!Interface.line)
                    val ((nextTokens',_),_) = Parser.Stream.get lexer
                in 
                    if Parser.sameToken(List.hd nextTokens',dummyEOF) 
                    then (TextIO.flushOut outStream; TextIO.closeOut outStream)
                    else 
                        let val (result,lexer) = invoke lexer 
                            val ((nextTokens,nextWord),lexer) = 
                                Parser.Stream.get lexer
                            val _ = app show result
                        in loop lexer end
                        handle ParseError => 
                               (TextIO.print 
                                    "Parse Error; ignoring this sentence.\n"; 
                                let val lexer =
                                        skip lexer (Tokens.PUNKT(!Interface.line,
                                                                 !Interface.line))
                                in loop lexer end)
                end
        in loop (Parser.makeLexer reader)
           before TextIO.closeIn stream
        end
  end

functor Parse (structure Algebra : PEIRCEfull) =
    ParseAux(structure Absyn = Absyn
             structure Algebra = Algebra
             structure Interface = Interface
             structure Parser = NL_Parser
             structure Tokens = NL_Vals.Tokens)

